@@ -178,8 +178,6 @@ def correct_C80_success_code(df):
     # Correcting non perfect conversions
     df.loc[(df['idCampaign']=='80')& 
             (df['BV'].notna()),'IDEmailStatus']==2
-    df.loc[df['idCampaign']=='80'& 
-            df['BV'].notna(),'BV']==np.nan
     aux=df.loc[(df['idCampaign'] == '80') &
             (df['IDEmailStatus'] ==31)].shape
     logger.info(f'C80 successes: {aux}')
